@@ -2,12 +2,13 @@ import string
 import re
 import math
 import operator
+from word_list import easy
 
 
 class textstatistics:
 
         def __init__(self):
-                return None
+            	return None
 
         def charcount(self, text, ignore_spaces=True):
                 if ignore_spaces:
@@ -135,7 +136,7 @@ class textstatistics:
 
         def difficult_words(self, text):
                 text_list = text.split()
-                filename = open('../textstat/easy_word_list').read().split()
+                filename = easy.list()
                 diff_words = []
                 for value in text_list:
                         if value not in filename:
@@ -226,3 +227,4 @@ class textstatistics:
                 return str(int(score)-1) + "th " + "and " + str(int(score)) + "th grade"
 
 textstat = textstatistics()
+
